Class: FBGraph::Selection
Constant Summary collapse
- OBJECTS =
%w(user album event group link note page photo post status video comment checkin friendlist thread order application apprequest subscription).freeze
- CONNECTION_TYPES =
%w(home photos comments feed noreply maybe invited attending declined picture members tagged links groups albums statuses videos notes posts events friends activities interests music books movies television likes inbox outbox updates accounts checkins friendlists platformrequests threads participants former_participants senders messages insights subscriptions payments apprequests reviews mutualfriends family).freeze
Instance Attribute Summary
Attributes inherited from Base
#connection_type, #last_result, #logger, #objects
Instance Method Summary collapse
Methods inherited from Base
#connection, #debug=, #delete!, #find, #info!, #initialize, #param, #params, #params=, #publish!, #with_fields
Constructor Details
This class inherits a constructor from FBGraph::Base
Instance Method Details
#me ⇒ Object
38 39 40 |
# File 'lib/fbgraph/selection.rb', line 38 def me find('me') end |
#metadata ⇒ Object
42 43 44 45 |
# File 'lib/fbgraph/selection.rb', line 42 def @params.merge!({:metadata => '1'}) self end |
#picture(type = 'square') ⇒ Object
47 48 49 50 51 |
# File 'lib/fbgraph/selection.rb', line 47 def picture(type='square') params = {:type => type} params.merge!(:access_token => @client.access_token) unless @client.access_token.blank? uri = [@client.facebook_uri , build_open_graph_path(@objects , 'picture' , params)].join('/') end |